(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     37654,       1261]*)
(*NotebookOutlinePosition[     38289,       1283]*)
(*  CellTagsIndexPosition[     38245,       1279]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Style Definitions", "Subtitle"],

Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Style Environment Names", "Section"],

Cell[StyleData[All, "Working"],
  PageWidth->WindowWidth,
  ScriptMinSize->9],

Cell[StyleData[All, "Presentation"],
  PageWidth->WindowWidth,
  ScriptMinSize->9],

Cell[StyleData[All, "SansSerif"],
  PageWidth->WindowWidth,
  ScriptMinSize->7,
  FontFamily->"Helvetica",
  FontSize->10],

Cell[StyleData[All, "SlideShow"],
  PageWidth->WindowWidth,
  ScrollingOptions->{"PagewiseDisplay"->True,
  "VerticalScrollRange"->Fit},
  ShowCellBracket->False,
  ScriptMinSize->9],

Cell[StyleData[All, "Printout"],
  PageWidth->PaperWidth,
  ScriptMinSize->7,
  FontSize->10,
  PrivateFontOptions->{"FontType"->"Outline"}],

Cell[StyleData[All, "SansSerifPrintout"],
  PageWidth->PaperWidth,
  ScriptMinSize->5,
  FontFamily->"Helvetica",
  FontSize->8,
  PrivateFontOptions->{"FontType"->"Outline"}]
}, Closed]],

Cell[CellGroupData[{

Cell["Notebook Options", "Section"],

Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],

Cell[StyleData["Notebook"],
  PageHeaders->{{Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
          TextData[ {
            ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
          TextData[ {
            ValueBox[ "FileName"]}], "Header"], None, Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"]}},
  CellFrameLabelMargins->6,
  DefaultNewCellStyle->"Text",
  DefaultDuplicateCellStyle->"Text",
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Headings", "Section"],

Cell[CellGroupData[{

Cell[StyleData["H1"],
  CellMargins->{{12, Inherited}, {20, 40}},
  CellGroupingRules->{"TitleGrouping", 0},
  ConversionRules:>{"HTML" -> {{"<span class='H1'>", "</span>"}, {
    "<h1 class='H1'>", "</h1>"}}},
  PageBreakBelow->False,
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
              FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
      "gridMathematica"->FormBox[ 
          RowBox[ {"grid", 
            AdjustmentBox[ 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], TextForm],
       "webMathematica"->FormBox[ 
          RowBox[ {"web", 
            AdjustmentBox[ 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], TextForm],
       Inherited},
  LineSpacing->{1, 13},
  CounterIncrements->"H1",
  CounterAssignments->{{"H2", 0}, {"H3", 0}, {"Equation", 0}, {"Figure", 0}, {
      "H4", 0}, {"H5", 0}, {"H6", 0}},
  FontSize->36,
  FontWeight->"Bold"],

Cell[StyleData["H1", "Presentation"],
  CellMargins->{{18, 10}, {40, 62}},
  FontSize->54],

Cell[StyleData["H1", "SansSerif"],
  FontSize->30,
  FontWeight->"Bold"],

Cell[StyleData["H1", "SlideShow"]],

Cell[StyleData["H1", "Printout"],
  CellMargins->{{2, 10}, {15, 30}},
  FontSize->30],

Cell[StyleData["H1", "SansSerifPrintout"],
  CellMargins->{{2, 10}, {15, 30}},
  FontSize->26]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["H2"],
  CellMargins->{{12, Inherited}, {10, 15}},
  CellGroupingRules->{"TitleGrouping", 10},
  ConversionRules:>{"HTML" -> {{"<span class='H2'>", "</span>"}, {
    "<h2 class='H2'>", "</h2>"}}},
  PageBreakBelow->False,
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
              FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
      "gridMathematica"->FormBox[ 
          RowBox[ {"grid", 
            AdjustmentBox[ 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], TextForm],
       "webMathematica"->FormBox[ 
          RowBox[ {"web", 
            AdjustmentBox[ 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], TextForm],
       Inherited},
  CounterIncrements->"H2",
  CounterAssignments->{{"H3", 0}, {"H4", 0}, {"Equation", 0}, {"Figure", 0}, {
      "H5", 0}, {"H6", 0}},
  FontSize->24,
  FontWeight->"Bold"],

Cell[StyleData["H2", "Presentation"],
  CellMargins->{{18, 10}, {24, 18}},
  FontSize->36],

Cell[StyleData["H2", "SansSerif"],
  FontSize->20],

Cell[StyleData["H2", "SlideShow"]],

Cell[StyleData["H2", "Printout"],
  CellMargins->{{2, 10}, {10, 15}},
  FontSize->20],

Cell[StyleData["H2", "SansSerifPrintout"],
  CellMargins->{{2, 10}, {10, 15}},
  FontSize->18]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["H3"],
  CellMargins->{{12, Inherited}, {10, 20}},
  CellGroupingRules->{"TitleGrouping", 20},
  ConversionRules:>{"HTML" -> {{"<span class='H3'>", "</span>"}, {
    "<h3 class='H3'>", "</h3>"}}},
  PageBreakBelow->False,
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
              FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
      "gridMathematica"->FormBox[ 
          RowBox[ {"grid", 
            AdjustmentBox[ 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], TextForm],
       "webMathematica"->FormBox[ 
          RowBox[ {"web", 
            AdjustmentBox[ 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], TextForm],
       Inherited},
  CounterIncrements->"H3",
  CounterAssignments->{{"H4", 0}, {"H5", 0}, {"Equation", 0}, {"Figure", 0}, {
      "H6", 0}},
  FontSize->18,
  FontWeight->"Bold"],

Cell[StyleData["H3", "Presentation"],
  CellMargins->{{18, 10}, {20, 22}},
  FontSize->27],

Cell[StyleData["H3", "SansSerif"],
  FontSize->16],

Cell[StyleData["H3", "SlideShow"]],

Cell[StyleData["H3", "Printout"],
  CellMargins->{{2, 10}, {8, 10}},
  FontSize->16],

Cell[StyleData["H3", "SansSerifPrintout"],
  CellMargins->{{2, 10}, {8, 10}},
  FontSize->14]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["H4"],
  CellMargins->{{12, Inherited}, {10, 20}},
  CellGroupingRules->{"SectionGrouping", 30},
  ConversionRules:>{"HTML" -> {{"<span class='H4'>", "</span>"}, {
    "<h4 class='H4'>", "</h4>"}}},
  PageBreakBelow->False,
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
              FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
      "gridMathematica"->FormBox[ 
          RowBox[ {"grid", 
            AdjustmentBox[ 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], TextForm],
       "webMathematica"->FormBox[ 
          RowBox[ {"web", 
            AdjustmentBox[ 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], TextForm],
       Inherited},
  CounterIncrements->"H4",
  CounterAssignments->{{"H5", 0}, {"H6", 0}, {"Equation", 0}, {"Figure", 0}},
  FontSize->14,
  FontWeight->"Bold"],

Cell[StyleData["H4", "Presentation"],
  CellMargins->{{16, 10}, {18, 22}},
  FontSize->21],

Cell[StyleData["H4", "SansSerif"],
  FontSize->12],

Cell[StyleData["H4", "SlideShow"]],

Cell[StyleData["H4", "Printout"],
  CellMargins->{{2, 10}, {8, 10}},
  FontSize->12],

Cell[StyleData["H4", "SansSerifPrintout"],
  CellMargins->{{2, 10}, {8, 10}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["H5"],
  CellMargins->{{12, Inherited}, {10, 20}},
  CellGroupingRules->{"SectionGrouping", 40},
  ConversionRules:>{"HTML" -> {{"<span class='H5'>", "</span>"}, {
    "<h5 class='H5'>", "</h5>"}}},
  PageBreakBelow->False,
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
              FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
      "gridMathematica"->FormBox[ 
          RowBox[ {"grid", 
            AdjustmentBox[ 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], TextForm],
       "webMathematica"->FormBox[ 
          RowBox[ {"web", 
            AdjustmentBox[ 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], TextForm],
       Inherited},
  CounterIncrements->"H5",
  CounterAssignments->{{"H6", 0}},
  FontWeight->"Bold"],

Cell[StyleData["H5", "Presentation"],
  CellMargins->{{18, 10}, {20, 26}},
  FontSize->18],

Cell[StyleData["H5", "SansSerif"]],

Cell[StyleData["H5", "SlideShow"]],

Cell[StyleData["H5", "Printout"],
  CellMargins->{{2, 10}, {8, 10}}],

Cell[StyleData["H5", "SansSerifPrintout"],
  CellMargins->{{2, 10}, {8, 10}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["H6"],
  CellMargins->{{12, Inherited}, {10, 20}},
  CellGroupingRules->{"SectionGrouping", 50},
  ConversionRules:>{"HTML" -> {{"<span class='H6'>", "</span>"}, {
    "<h6 class='H6'>", "</h6>"}}},
  PageBreakBelow->False,
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
              FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
      "gridMathematica"->FormBox[ 
          RowBox[ {"grid", 
            AdjustmentBox[ 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], TextForm],
       "webMathematica"->FormBox[ 
          RowBox[ {"web", 
            AdjustmentBox[ 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], TextForm],
       Inherited},
  CounterIncrements->"H6",
  FontSize->10,
  FontWeight->"Bold"],

Cell[StyleData["H6", "Presentation"],
  CellMargins->{{18, 10}, {20, 26}},
  FontSize->15],

Cell[StyleData["H6", "SansSerif"],
  FontSize->9,
  FontTracking->"Extended"],

Cell[StyleData["H6", "SlideShow"]],

Cell[StyleData["H6", "Printout"],
  CellMargins->{{2, 10}, {8, 10}},
  FontSize->8.5],

Cell[StyleData["H6", "SansSerifPrintout"],
  CellMargins->{{2, 10}, {8, 10}},
  FontSize->7.5]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Body Text", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Body"],
  CellMargins->{{14, 10}, {7, 7}},
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
              FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
      "gridMathematica"->FormBox[ 
          RowBox[ {"grid", 
            AdjustmentBox[ 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], TextForm],
       "webMathematica"->FormBox[ 
          RowBox[ {"web", 
            AdjustmentBox[ 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], TextForm],
       Inherited},
  LineSpacing->{1, 3},
  CounterIncrements->"Body"],

Cell[StyleData["Body", "Presentation"],
  CellMargins->{{20, 10}, {10, 10}},
  FontSize->18],

Cell[StyleData["Body", "SansSerif"]],

Cell[StyleData["Body", "SlideShow"]],

Cell[StyleData["Body", "Printout"],
  CellMargins->{{2, 2}, {6, 6}}],

Cell[StyleData["Body", "SansSerifPrintout"],
  CellMargins->{{2, 2}, {6, 6}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["LI"],
  CellDingbat->"\[FilledSmallCircle]",
  CellMargins->{{23, 10}, {7, 7}},
  ConversionRules:>{"HTML" -> {{"<span class='LI'>", "</span>"}, {
    "<ul class='LI'><li class='LI'>", "</li></ul>"}}},
  LineSpacing->{1, 3},
  CounterIncrements->"LI"],

Cell[StyleData["LI", "Presentation"],
  CellMargins->{{32, 10}, {10, 10}},
  FontSize->18],

Cell[StyleData["LI", "SansSerif"],
  CellMargins->{{25, 10}, {7, 7}}],

Cell[StyleData["LI", "SlideShow"]],

Cell[StyleData["LI", "Printout"],
  CellMargins->{{12, 2}, {6, 6}}],

Cell[StyleData["LI", "SansSerifPrintout"],
  CellMargins->{{12, 2}, {6, 6}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Input/Output", "Section"],

Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Input"],
  CellMargins->{{45, 10}, {5, 7}},
  Evaluatable->True,
  CellGroupingRules->"InputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultInputFormatType,
  "TwoByteSyntaxCharacterAutoReplacement"->True,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  AutoItalicWords->{},
  LanguageCategory->"Formula",
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  LinebreakAdjustments->{0.85, 2, 10, 0, 1},
  CounterIncrements->"Input",
  FontWeight->"Bold"],

Cell[StyleData["Input", "Presentation"],
  CellMargins->{{64, 10}, {6, 10}},
  FontSize->18],

Cell[StyleData["Input", "SansSerif"],
  FontSize->12],

Cell[StyleData["Input", "SlideShow"]],

Cell[StyleData["Input", "Printout"],
  CellMargins->{{39, 0}, {4, 6}},
  LinebreakAdjustments->{0.85, 2, 10, 1, 1},
  FontSize->9],

Cell[StyleData["Input", "SansSerifPrintout"],
  CellMargins->{{39, 0}, {4, 6}},
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Output"],
  CellMargins->{{47, 10}, {7, 5}},
  CellEditDuplicate->True,
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  "TwoByteSyntaxCharacterAutoReplacement"->True,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  AutoItalicWords->{},
  LanguageCategory->"Formula",
  FormatType->InputForm,
  CounterIncrements->"Output"],

Cell[StyleData["Output", "Presentation"],
  CellMargins->{{66, 10}, {10, 6}},
  FontSize->18],

Cell[StyleData["Output", "SansSerif"],
  FontSize->12],

Cell[StyleData["Output", "SlideShow"]],

Cell[StyleData["Output", "Printout"],
  CellMargins->{{39, 0}, {6, 4}},
  FontSize->9],

Cell[StyleData["Output", "SansSerifPrintout"],
  CellMargins->{{39, 0}, {6, 4}},
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Message"],
  CellMargins->{{45, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"OutputGrouping",
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  "TwoByteSyntaxCharacterAutoReplacement"->True,
  AutoStyleOptions->{"UnmatchedBracketStyle"->None},
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  AutoItalicWords->{},
  FormatType->InputForm,
  CounterIncrements->"Message",
  StyleMenuListing->None,
  FontColor->RGBColor[0, 0, 1]],

Cell[StyleData["Message", "Presentation"],
  CellMargins->{{64, 10}, {6, 6}},
  FontSize->18],

Cell[StyleData["Message", "SansSerif"],
  FontSize->12],

Cell[StyleData["Message", "SlideShow"]],

Cell[StyleData["Message", "Printout"],
  CellMargins->{{39, Inherited}, {Inherited, Inherited}},
  FontSize->8,
  FontColor->GrayLevel[0]],

Cell[StyleData["Message", "SansSerifPrintout"],
  CellMargins->{{39, Inherited}, {Inherited, Inherited}},
  FontSize->8,
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Print"],
  CellMargins->{{45, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  "TwoByteSyntaxCharacterAutoReplacement"->True,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  AutoItalicWords->{},
  FormatType->InputForm,
  CounterIncrements->"Print",
  StyleMenuListing->None],

Cell[StyleData["Print", "Presentation"],
  CellMargins->{{64, 10}, {6, 6}},
  FontSize->18],

Cell[StyleData["Print", "SansSerif"],
  FontSize->12],

Cell[StyleData["Print", "SlideShow"]],

Cell[StyleData["Print", "Printout"],
  CellMargins->{{39, Inherited}, {Inherited, Inherited}},
  FontSize->8],

Cell[StyleData["Print", "SansSerifPrintout"],
  CellMargins->{{39, Inherited}, {Inherited, Inherited}},
  FontSize->8]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Graphics"],
  CellMargins->{{45, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"GraphicsGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  DefaultFormatType->DefaultOutputFormatType,
  FormatType->InputForm,
  CounterIncrements->"Graphics",
  ImageMargins->{{43, Inherited}, {Inherited, 0}},
  StyleMenuListing->None],

Cell[StyleData["Graphics", "Presentation"],
  CellMargins->{{64, 10}, {6, 6}},
  FontSize->18],

Cell[StyleData["Graphics", "SansSerif"],
  FontSize->12],

Cell[StyleData["Graphics", "SlideShow"]],

Cell[StyleData["Graphics", "Printout"],
  CellMargins->{{39, Inherited}, {Inherited, Inherited}},
  ImageSize->{250, 250},
  FontSize->9],

Cell[StyleData["Graphics", "SansSerifPrintout"],
  CellMargins->{{39, Inherited}, {Inherited, Inherited}},
  ImageSize->{250, 250},
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["CellLabel"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->9,
  FontColor->RGBColor[0, 0, 1]],

Cell[StyleData["CellLabel", "Presentation"],
  FontSize->14],

Cell[StyleData["CellLabel", "SansSerif"]],

Cell[StyleData["CellLabel", "SlideShow"]],

Cell[StyleData["CellLabel", "Printout"],
  FontFamily->"Courier",
  FontSize->8,
  FontSlant->"Italic",
  FontColor->GrayLevel[0]],

Cell[StyleData["CellLabel", "SansSerifPrintout"],
  FontSize->7,
  FontColor->GrayLevel[0]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Hyperlink Styles", "Section"],

Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Hyperlink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookLocate[ #2]}]&),
  Active->True,
  ButtonNote->ButtonData}],

Cell[StyleData["Hyperlink", "SansSerif"]],

Cell[StyleData["Hyperlink", "SlideShow"]],

Cell[StyleData["Hyperlink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["Hyperlink", "SansSerifPrintout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["MainBookLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["MainBookLink", "SansSerif"]],

Cell[StyleData["MainBookLink", "SlideShow"]],

Cell[StyleData["MainBookLink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["MainBookLink", "SansSerifPrintout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["AddOnsLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontFamily->"Courier",
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["AddOnsLink", "SansSerif"]],

Cell[StyleData["AddOnLink", "SlideShow"]],

Cell[StyleData["AddOnLink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["AddOnLink", "SansSerifPrintout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefGuideLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontFamily->"Courier",
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["RefGuideLink", "SansSerif"]],

Cell[StyleData["RefGuideLink", "SlideShow"]],

Cell[StyleData["RefGuideLink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["RefGuideLink", "SansSerifPrintout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["GettingStartedLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["GettingStartedLink", "SansSerif"]],

Cell[StyleData["GettingStartedLink", "SlideShow"]],

Cell[StyleData["GettingStartedLink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["GettingStartedLink", "SansSerifPrintout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["OtherInformationLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["OtherInformationLink", "SansSerif"]],

Cell[StyleData["OtherInformationLink", "SlideShow"]],

Cell[StyleData["OtherInformationLink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["OtherInformationLink", "SansSerifPrintout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["DemosLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "Demos", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["DemosLink", "SlideShow"]],

Cell[StyleData["DemosLink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["DemosLink", "SansSerifPrintout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["TourLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "Tour", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["TourLink", "SlideShow"]],

Cell[StyleData["TourLink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["TourLink", "SansSerifPrintout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["MasterIndexLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "MasterIndex", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["MasterIndexLink", "SlideShow"]],

Cell[StyleData["MasterIndexLink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["MasterIndexLink", "SansSerifPrintout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Palette Styles", "Section"],

Cell["\<\
The cells below define styles that define standard ButtonFunctions, \
for use in palette buttons.\
\>", "Text"],

Cell[StyleData["Paste"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, After]}]&)}],

Cell[StyleData["Evaluate"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      FrontEnd`SelectionEvaluate[ 
        FrontEnd`InputNotebook[ ], All]}]&)}],

Cell[StyleData["EvaluateCell"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      FrontEnd`SelectionMove[ 
        FrontEnd`InputNotebook[ ], All, Cell, 1], 
      FrontEnd`SelectionEvaluateCreateCell[ 
        FrontEnd`InputNotebook[ ], All]}]&)}],

Cell[StyleData["CopyEvaluate"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`SelectionCreateCell[ 
        FrontEnd`InputNotebook[ ], All], 
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      FrontEnd`SelectionEvaluate[ 
        FrontEnd`InputNotebook[ ], All]}]&)}],

Cell[StyleData["CopyEvaluateCell"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`SelectionCreateCell[ 
        FrontEnd`InputNotebook[ ], All], 
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      FrontEnd`SelectionEvaluateCreateCell[ 
        FrontEnd`InputNotebook[ ], All]}]&)}]
}, Closed]],

Cell[CellGroupData[{

Cell["Slide Show Styles", "Section"],

Cell[CellGroupData[{

Cell[StyleData["SlideShowNavigationBar"],
  Editable->False,
  CellFrame->True,
  CellMargins->{{0, 0}, {3, 3}},
  CellElementSpacings->{"CellMinHeight"->0.8125},
  CellGroupingRules->{"SectionGrouping", 30},
  CellFrameMargins->False,
  CellFrameColor->GrayLevel[1],
  CellFrameLabelMargins->False,
  TextAlignment->Center,
  CounterIncrements->"SlideShowNavigationBar",
  StyleMenuListing->None,
  FontSize->10,
  Background->GrayLevel[0.8],
  Magnification->1,
  GridBoxOptions->{GridBaseline->Center,
  RowSpacings->0,
  ColumnSpacings->0,
  ColumnWidths->{3.5, 3.5, 3.5, 3.5, 13, 5, 4},
  RowAlignments->Baseline,
  ColumnAlignments->{
    Center, Center, Center, Center, Center, Center, Right, Center}}],

Cell[StyleData["SlideShowNavigationBar", "Presentation"]],

Cell[StyleData["SlideShowNavigationBar", "SlideShow"],
  Deletable->False,
  ShowCellBracket->False,
  CellMargins->{{-1, -1}, {-1, -1}},
  PageBreakAbove->True,
  CellFrameMargins->{{1, 1}, {0, 0}}],

Cell[StyleData["SlideShowNavigationBar", "Printout"],
  CellMargins->{{18, 4}, {4, 4}},
  LineSpacing->{1, 3},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["SlideShowSection"],
  CellFrame->{{0, 0}, {0, 0.5}},
  CellMargins->{{0, 0}, {10, 0}},
  CellGroupingRules->{"SectionGrouping", 40},
  PageBreakBelow->False,
  CellFrameMargins->{{12, 4}, {6, 12}},
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
              FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
      "gridMathematica"->FormBox[ 
          RowBox[ {"grid", 
            AdjustmentBox[ 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
      "webMathematica"->FormBox[ 
          RowBox[ {"web", 
            AdjustmentBox[ 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], TextForm],
       Inherited},
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->18,
  FontWeight->"Plain",
  FontColor->GrayLevel[1],
  Background->RGBColor[0.408011, 0.440726, 0.8]],

Cell[StyleData["SlideShowSection", "Presentation"],
  CellFrameMargins->{{20, 10}, {10, 18}},
  FontSize->27],

Cell[StyleData["SlideShowSection", "SlideShow"],
  ShowCellBracket->False,
  PageBreakAbove->True],

Cell[StyleData["SlideShowSection", "Printout"],
  CellMargins->{{18, 30}, {0, 30}},
  CellFrameMargins->5,
  FontSize->14]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["SlideHyperlink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontSize->26,
  FontColor->GrayLevel[0.400015],
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookLocate[ #2]}]&),
  Active->True,
  ButtonMinHeight->0.85,
  ButtonMargins->0.5,
  ButtonNote->None}],

Cell[StyleData["SlideHyperlink", "Presentation"],
  CellMargins->{{14, 10}, {6, 12}},
  FontSize->36],

Cell[StyleData["SlideHyperlink", "SlideShow"]],

Cell[StyleData["SlideHyperlink", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["SlideTOCLink"],
  CellMargins->{{24, Inherited}, {Inherited, Inherited}},
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontFamily->"Helvetica",
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookLocate[ #2]}]&),
  Active->True,
  ButtonMargins->1.5,
  ButtonNote->ButtonData}],

Cell[StyleData["SlideTOCLink", "Presentation"],
  CellMargins->{{35, 10}, {8, 8}},
  FontSize->18],

Cell[StyleData["SlideTOCLink", "SlideShow"]],

Cell[StyleData["SlideTOCLink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["SlideTOC"],
  CellDingbat->"\[Bullet]",
  CellMargins->{{18, Inherited}, {Inherited, Inherited}},
  StyleMenuListing->None,
  FontFamily->"Helvetica"],

Cell[StyleData["SlideTOC", "Presentation"],
  CellMargins->{{25, 10}, {10, 5}},
  FontSize->18],

Cell[StyleData["SlideTOC", "SlideShow"],
  FontSize->14],

Cell[StyleData["SlideTOC", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0]]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Macintosh",
ScreenRectangle->{{4, 1152}, {0, 746}},
WindowSize->{500, 500},
WindowMargins->{{1, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 37, 0, 52, "Subtitle"],
Cell[1816, 55, 193, 4, 50, "Text"],

Cell[CellGroupData[{
Cell[2034, 63, 42, 0, 69, "Section"],
Cell[2079, 65, 77, 2, 38, 31, 0, "StyleData", "All", "Working"],
Cell[2159, 69, 82, 2, 38, 36, 0, "StyleData", "All", "Presentation"],
Cell[2244, 73, 122, 4, 35, 33, 0, "StyleData", "All", "SansSerif"],
Cell[2369, 79, 182, 5, 38, 33, 0, "StyleData", "All", "SlideShow"],
Cell[2554, 86, 140, 4, 34, 32, 0, "StyleData", "All", "Printout"],
Cell[2697, 92, 175, 5, 32, 41, 0, "StyleData", "All", "SansSerifPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[2909, 102, 35, 0, 39, "Section"],
Cell[2947, 104, 101, 3, 32, "Text"],
Cell[3051, 109, 494, 13, 38, 27, 0, "StyleData", "Notebook", "All",
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[3582, 127, 38, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[3645, 131, 1659, 38, 112, 21, 0, "StyleData", "H1", "All",
  CounterIncrements->"H1",
  CounterAssignments->{{"H2", 0}, {"H3", 0}, {"Equation", 0}, {"Figure", 0}, {
      "H4", 0}, {"H5", 0}, {"H6", 0}}],
Cell[5307, 171, 90, 2, 172, 37, 0, "StyleData", "H1", "Presentation"],
Cell[5400, 175, 72, 2, 106, 34, 0, "StyleData", "H1", "SansSerif"],
Cell[5475, 179, 34, 0, 112, 34, 0, "StyleData", "H1", "SlideShow"],
Cell[5512, 181, 85, 2, 91, 33, 0, "StyleData", "H1", "Printout"],
Cell[5600, 185, 94, 2, 87, 42, 0, "StyleData", "H1", "SansSerifPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[5731, 192, 1625, 37, 69, 21, 0, "StyleData", "H2", "All",
  CounterIncrements->"H2",
  CounterAssignments->{{"H3", 0}, {"H4", 0}, {"Equation", 0}, {"Figure", 0}, {
      "H5", 0}, {"H6", 0}}],
Cell[7359, 231, 90, 2, 94, 37, 0, "StyleData", "H2", "Presentation"],
Cell[7452, 235, 50, 1, 61, 34, 0, "StyleData", "H2", "SansSerif"],
Cell[7505, 238, 34, 0, 69, 34, 0, "StyleData", "H2", "SlideShow"],
Cell[7542, 240, 85, 2, 61, 33, 0, "StyleData", "H2", "Printout"],
Cell[7630, 244, 94, 2, 62, 42, 0, "StyleData", "H2", "SansSerifPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[7761, 251, 1614, 37, 67, 21, 0, "StyleData", "H3", "All",
  CounterIncrements->"H3",
  CounterAssignments->{{"H4", 0}, {"H5", 0}, {"Equation", 0}, {"Figure", 0}, {
      "H6", 0}}],
Cell[9378, 290, 90, 2, 85, 37, 0, "StyleData", "H3", "Presentation"],
Cell[9471, 294, 50, 1, 62, 34, 0, "StyleData", "H3", "SansSerif"],
Cell[9524, 297, 34, 0, 67, 34, 0, "StyleData", "H3", "SlideShow"],
Cell[9561, 299, 84, 2, 50, 33, 0, "StyleData", "H3", "Printout"],
Cell[9648, 303, 93, 2, 50, 42, 0, "StyleData", "H3", "SansSerifPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[9778, 310, 1598, 36, 62, 21, 0, "StyleData", "H4", "All",
  CounterIncrements->"H4",
  CounterAssignments->{{"H5", 0}, {"H6", 0}, {"Equation", 0}, {
      "Figure", 0}}],
Cell[11379, 348, 90, 2, 77, 37, 0, "StyleData", "H4", "Presentation"],
Cell[11472, 352, 50, 1, 60, 34, 0, "StyleData", "H4", "SansSerif"],
Cell[11525, 355, 34, 0, 62, 34, 0, "StyleData", "H4", "SlideShow"],
Cell[11562, 357, 84, 2, 48, 33, 0, "StyleData", "H4", "Printout"],
Cell[11649, 361, 93, 2, 45, 42, 0, "StyleData", "H4", "SansSerifPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[11779, 368, 1539, 35, 60, 21, 0, "StyleData", "H5", "All",
  CounterIncrements->"H5",
  CounterAssignments->{{"H6", 0}}],
Cell[13321, 405, 90, 2, 83, 37, 0, "StyleData", "H5", "Presentation"],
Cell[13414, 409, 34, 0, 60, 34, 0, "StyleData", "H5", "SansSerif"],
Cell[13451, 411, 34, 0, 60, 34, 0, "StyleData", "H5", "SlideShow"],
Cell[13488, 413, 68, 1, 48, 33, 0, "StyleData", "H5", "Printout"],
Cell[13559, 416, 77, 1, 48, 42, 0, "StyleData", "H5", "SansSerifPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[13673, 422, 1520, 35, 57, 21, 0, "StyleData", "H6", "All",
  CounterIncrements->"H6"],
Cell[15196, 459, 90, 2, 77, 37, 0, "StyleData", "H6", "Presentation"],
Cell[15289, 463, 77, 2, 56, 34, 0, "StyleData", "H6", "SansSerif"],
Cell[15369, 467, 34, 0, 57, 34, 0, "StyleData", "H6", "SlideShow"],
Cell[15406, 469, 85, 2, 44, 33, 0, "StyleData", "H6", "Printout"],
Cell[15494, 473, 94, 2, 42, 42, 0, "StyleData", "H6", "SansSerifPrintout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[15637, 481, 39, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[15701, 485, 1327, 30, 44, 23, 0, "StyleData", "Body", "All",
  CounterIncrements->"Body"],
Cell[17031, 517, 92, 2, 56, 39, 0, "StyleData", "Body", "Presentation"],
Cell[17126, 521, 36, 0, 44, 36, 0, "StyleData", "Body", "SansSerif"],
Cell[17165, 523, 36, 0, 44, 36, 0, "StyleData", "Body", "SlideShow"],
Cell[17204, 525, 68, 1, 42, 35, 0, "StyleData", "Body", "Printout"],
Cell[17275, 528, 77, 1, 42, 44, 0, "StyleData", "Body", "SansSerifPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[17389, 534, 267, 6, 44, 21, 0, "StyleData", "LI", "All",
  CounterIncrements->"LI"],
Cell[17659, 542, 90, 2, 56, 37, 0, "StyleData", "LI", "Presentation"],
Cell[17752, 546, 69, 1, 44, 34, 0, "StyleData", "LI", "SansSerif"],
Cell[17824, 549, 34, 0, 44, 34, 0, "StyleData", "LI", "SlideShow"],
Cell[17861, 551, 67, 1, 42, 33, 0, "StyleData", "LI", "Printout"],
Cell[17931, 554, 76, 1, 42, 42, 0, "StyleData", "LI", "SansSerifPrintout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[18056, 561, 42, 0, 39, "Section"],
Cell[18101, 563, 248, 5, 68, "Text"],

Cell[CellGroupData[{
Cell[18374, 572, 659, 18, 42, 24, 0, "StyleData", "Input", "All",
  CounterIncrements->"Input"],
Cell[19036, 592, 92, 2, 53, 40, 0, "StyleData", "Input", "Presentation"],
Cell[19131, 596, 53, 1, 42, 37, 0, "StyleData", "Input", "SansSerif"],
Cell[19187, 599, 37, 0, 42, 37, 0, "StyleData", "Input", "SlideShow"],
Cell[19227, 601, 130, 3, 36, 36, 0, "StyleData", "Input", "Printout"],
Cell[19360, 606, 94, 2, 36, 45, 0, "StyleData", "Input", "SansSerifPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[19491, 613, 601, 16, 42, 25, 0, "StyleData", "Output", "All",
  CounterIncrements->"Output"],
Cell[20095, 631, 93, 2, 52, 41, 0, "StyleData", "Output", "Presentation"],
Cell[20191, 635, 54, 1, 42, 38, 0, "StyleData", "Output", "SansSerif"],
Cell[20248, 638, 38, 0, 42, 38, 0, "StyleData", "Output", "SlideShow"],
Cell[20289, 640, 86, 2, 36, 37, 0, "StyleData", "Output", "Printout"],
Cell[20378, 644, 95, 2, 36, 46, 0, "StyleData", "Output", \
"SansSerifPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[20510, 651, 670, 17, 38, 26, 0, "StyleData", "Message", "All",
  CounterIncrements->"Message",
  StyleMenuListing->None],
Cell[21183, 670, 93, 2, 48, 42, 0, "StyleData", "Message", "Presentation"],
Cell[21279, 674, 55, 1, 38, 39, 0, "StyleData", "Message", "SansSerif"],
Cell[21337, 677, 39, 0, 38, 39, 0, "StyleData", "Message", "SlideShow"],
Cell[21379, 679, 138, 3, 32, 38, 0, "StyleData", "Message", "Printout"],
Cell[21520, 684, 147, 3, 32, 47, 0, "StyleData", "Message", \
"SansSerifPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[21704, 692, 614, 16, 38, 24, 0, "StyleData", "Print", "All",
  CounterIncrements->"Print",
  StyleMenuListing->None],
Cell[22321, 710, 91, 2, 48, 40, 0, "StyleData", "Print", "Presentation"],
Cell[22415, 714, 53, 1, 38, 37, 0, "StyleData", "Print", "SansSerif"],
Cell[22471, 717, 37, 0, 38, 37, 0, "StyleData", "Print", "SlideShow"],
Cell[22511, 719, 109, 2, 32, 36, 0, "StyleData", "Print", "Printout"],
Cell[22623, 723, 118, 2, 32, 45, 0, "StyleData", "Print", \
"SansSerifPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[22778, 730, 440, 12, 38, 27, 0, "StyleData", "Graphics", "All",
  CounterIncrements->"Graphics",
  StyleMenuListing->None],
Cell[23221, 744, 94, 2, 48, 43, 0, "StyleData", "Graphics", "Presentation"],
Cell[23318, 748, 56, 1, 38, 40, 0, "StyleData", "Graphics", "SansSerif"],
Cell[23377, 751, 40, 0, 38, 40, 0, "StyleData", "Graphics", "SlideShow"],
Cell[23420, 753, 137, 3, 34, 39, 0, "StyleData", "Graphics", "Printout"],
Cell[23560, 758, 146, 3, 34, 48, 0, "StyleData", "Graphics", \
"SansSerifPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[23743, 766, 128, 4, 34, 28, 0, "StyleData", "CellLabel", "All",
  StyleMenuListing->None],
Cell[23874, 772, 60, 1, 40, 44, 0, "StyleData", "CellLabel", "Presentation"],
Cell[23937, 775, 41, 0, 34, 41, 0, "StyleData", "CellLabel", "SansSerif"],
Cell[23981, 777, 41, 0, 34, 41, 0, "StyleData", "CellLabel", "SlideShow"],
Cell[24025, 779, 130, 4, 32, 40, 0, "StyleData", "CellLabel", "Printout"],
Cell[24158, 785, 91, 2, 31, 49, 0, "StyleData", "CellLabel", \
"SansSerifPrintout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[24298, 793, 35, 0, 39, "Section"],
Cell[24336, 795, 184, 4, 50, "Text"],

Cell[CellGroupData[{
Cell[24545, 803, 302, 8, 38, 28, 0, "StyleData", "Hyperlink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[24850, 813, 41, 0, 38, 41, 0, "StyleData", "Hyperlink", "SansSerif"],
Cell[24894, 815, 41, 0, 38, 41, 0, "StyleData", "Hyperlink", "SlideShow"],
Cell[24938, 817, 107, 2, 38, 40, 0, "StyleData", "Hyperlink", "Printout"],
Cell[25048, 821, 116, 2, 38, 49, 0, "StyleData", "Hyperlink", \
"SansSerifPrintout"]
}, Closed]],
Cell[25179, 826, 104, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[25308, 833, 316, 8, 38, 31, 0, "StyleData", "MainBookLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[25627, 843, 44, 0, 38, 44, 0, "StyleData", "MainBookLink", "SansSerif"],
Cell[25674, 845, 44, 0, 38, 44, 0, "StyleData", "MainBookLink", "SlideShow"],
Cell[25721, 847, 110, 2, 38, 43, 0, "StyleData", "MainBookLink", "Printout"],
Cell[25834, 851, 119, 2, 38, 52, 0, "StyleData", "MainBookLink", \
"SansSerifPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[25990, 858, 337, 9, 37, 29, 0, "StyleData", "AddOnsLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[26330, 869, 42, 0, 37, 42, 0, "StyleData", "AddOnsLink", "SansSerif"],
Cell[26375, 871, 41, 0, 38, 41, 0, "StyleData", "AddOnLink", "SlideShow"],
Cell[26419, 873, 107, 2, 38, 40, 0, "StyleData", "AddOnLink", "Printout"],
Cell[26529, 877, 116, 2, 38, 49, 0, "StyleData", "AddOnLink", \
"SansSerifPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[26682, 884, 345, 9, 37, 31, 0, "StyleData", "RefGuideLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[27030, 895, 44, 0, 37, 44, 0, "StyleData", "RefGuideLink", "SansSerif"],
Cell[27077, 897, 44, 0, 37, 44, 0, "StyleData", "RefGuideLink", "SlideShow"],
Cell[27124, 899, 110, 2, 37, 43, 0, "StyleData", "RefGuideLink", "Printout"],
Cell[27237, 903, 119, 2, 37, 52, 0, "StyleData", "RefGuideLink", \
"SansSerifPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[27393, 910, 328, 8, 38, 37, 0, "StyleData", "GettingStartedLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[27724, 920, 50, 0, 38, 50, 0, "StyleData", "GettingStartedLink", \
"SansSerif"],
Cell[27777, 922, 50, 0, 38, 50, 0, "StyleData", "GettingStartedLink", \
"SlideShow"],
Cell[27830, 924, 116, 2, 38, 49, 0, "StyleData", "GettingStartedLink", \
"Printout"],
Cell[27949, 928, 125, 2, 38, 58, 0, "StyleData", "GettingStartedLink", \
"SansSerifPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[28111, 935, 332, 8, 38, 39, 0, "StyleData", "OtherInformationLink", \
"All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[28446, 945, 52, 0, 38, 52, 0, "StyleData", "OtherInformationLink", \
"SansSerif"],
Cell[28501, 947, 52, 0, 38, 52, 0, "StyleData", "OtherInformationLink", \
"SlideShow"],
Cell[28556, 949, 118, 2, 38, 51, 0, "StyleData", "OtherInformationLink", \
"Printout"],
Cell[28677, 953, 127, 2, 38, 60, 0, "StyleData", "OtherInformationLink", \
"SansSerifPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[28841, 960, 310, 8, 38, 28, 0, "StyleData", "DemosLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[29154, 970, 41, 0, 38, 41, 0, "StyleData", "DemosLink", "SlideShow"],
Cell[29198, 972, 107, 2, 38, 40, 0, "StyleData", "DemosLink", "Printout"],
Cell[29308, 976, 116, 2, 38, 49, 0, "StyleData", "DemosLink", \
"SansSerifPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[29461, 983, 308, 8, 38, 27, 0, "StyleData", "TourLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[29772, 993, 40, 0, 38, 40, 0, "StyleData", "TourLink", "SlideShow"],
Cell[29815, 995, 106, 2, 38, 39, 0, "StyleData", "TourLink", "Printout"],
Cell[29924, 999, 115, 2, 38, 48, 0, "StyleData", "TourLink", \
"SansSerifPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[30076, 1006, 322, 8, 38, 34, 0, "StyleData", "MasterIndexLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[30401, 1016, 47, 0, 38, 47, 0, "StyleData", "MasterIndexLink", \
"SlideShow"],
Cell[30451, 1018, 113, 2, 38, 46, 0, "StyleData", "MasterIndexLink", \
"Printout"],
Cell[30567, 1022, 122, 2, 38, 55, 0, "StyleData", "MasterIndexLink", \
"SansSerifPrintout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[30738, 1030, 33, 0, 39, "Section"],
Cell[30774, 1032, 121, 3, 50, "Text"],
Cell[30898, 1037, 226, 5, 38, 24, 0, "StyleData", "Paste", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[31127, 1044, 304, 7, 38, 27, 0, "StyleData", "Evaluate", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[31434, 1053, 400, 9, 38, 31, 0, "StyleData", "EvaluateCell", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[31837, 1064, 387, 9, 38, 31, 0, "StyleData", "CopyEvaluate", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[32227, 1075, 401, 9, 38, 35, 0, "StyleData", "CopyEvaluateCell", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic]
}, Closed]],

Cell[CellGroupData[{
Cell[32665, 1089, 36, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[32726, 1093, 709, 21, 33, 41, 0, "StyleData", "SlideShowNavigationBar", \
"All",
  CounterIncrements->"SlideShowNavigationBar",
  StyleMenuListing->None],
Cell[33438, 1116, 57, 0, 70, 57, 0, "StyleData", "SlideShowNavigationBar", \
"Presentation"],
Cell[33498, 1118, 199, 5, 70, 54, 0, "StyleData", "SlideShowNavigationBar", \
"SlideShow"],
Cell[33700, 1125, 126, 3, 70, 53, 0, "StyleData", "SlideShowNavigationBar", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[33863, 1133, 1681, 40, 69, 35, 0, "StyleData", "SlideShowSection", "All",
  
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
  StyleMenuListing->None],
Cell[35547, 1175, 109, 2, 70, 51, 0, "StyleData", "SlideShowSection", \
"Presentation"],
Cell[35659, 1179, 98, 2, 70, 48, 0, "StyleData", "SlideShowSection", \
"SlideShow"],
Cell[35760, 1183, 122, 3, 70, 47, 0, "StyleData", "SlideShowSection", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[35919, 1191, 327, 10, 50, 33, 0, "StyleData", "SlideHyperlink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[36249, 1203, 101, 2, 70, 49, 0, "StyleData", "SlideHyperlink", \
"Presentation"],
Cell[36353, 1207, 46, 0, 70, 46, 0, "StyleData", "SlideHyperlink", \
"SlideShow"],
Cell[36402, 1209, 128, 3, 70, 45, 0, "StyleData", "SlideHyperlink", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[36567, 1217, 341, 9, 38, 31, 0, "StyleData", "SlideTOCLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[36911, 1228, 98, 2, 70, 47, 0, "StyleData", "SlideTOCLink", \
"Presentation"],
Cell[37012, 1232, 44, 0, 70, 44, 0, "StyleData", "SlideTOCLink", \
"SlideShow"],
Cell[37059, 1234, 110, 2, 70, 43, 0, "StyleData", "SlideTOCLink", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[37206, 1241, 166, 4, 38, 27, 0, "StyleData", "SlideTOC", "All",
  StyleMenuListing->None],
Cell[37375, 1247, 95, 2, 70, 43, 0, "StyleData", "SlideTOC", "Presentation"],
Cell[37473, 1251, 56, 1, 70, 40, 0, "StyleData", "SlideTOC", "SlideShow"],
Cell[37532, 1254, 82, 2, 70, 39, 0, "StyleData", "SlideTOC", "Printout"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

